@@ -14,7 +14,7 @@ use Data::Object::ClassHas;
 with 'Data::Object::Role::Pluggable';
 with 'Data::Object::Role::Throwable';
 
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 # ATTRIBUTES
 
@@ -351,6 +351,11 @@ method serialize() {
   return $data;
 }
 
+method simple(Str $level = $self->level) {
+
+  return $self->report('simple', $level);
+}
+
 method succinct(Str $level = $self->level) {
 
   return $self->report('succinct', $level);
@@ -393,7 +398,7 @@ method warn(Str @messages) {
 
 =head1 NAME
 
-FlightRecorder
+FlightRecorder - Structured Logging
 
 =cut
 
@@ -752,6 +757,25 @@ a C<hashref>.
 
 =cut
 
+=head2 simple
+
+  simple() : Object
+
+The simple method loads and returns the
+L<FlightRecorder::Plugin::ReportSimple> report plugin.
+
+=over 4
+
+=item simple example #1
+
+  # given: synopsis
+
+  $f->simple
+
+=back
+
+=cut
+
 =head2 succinct
 
   succinct() : Object
